#Region ;**** Directives created by AutoIt3Wrapper_GUI ****
#AutoIt3Wrapper_Icon=netshell_193.ico
#AutoIt3Wrapper_UseUpx=n
#AutoIt3Wrapper_Res_Icon_Add=netshell_190.ico
#EndRegion ;**** Directives created by AutoIt3Wrapper_GUI ****

#comments-start

ConnStat - Connection Status

ConnStat.exe <adapter> [delay]

where: <adapter >= NIC adapter name as given under Windows Network Connections, use quotes if necessary
            [delay]       = Optional delay before monitoring starts (in seconds)

eg.  ConnStat.exe "Local Area Connection" 30

Tray icon will  change colour at the end of the delay period, (if given), to indicate monitoring has begun.

If the NIC given does not exist or is does not have a status of Connected, the program will exit.

NIC status will be checked every 1000 milliseconds.

ConnStat can be terminated by causing the NIC to disconnect, (eg. pull the cable), or choosing Exit from the icon context menu.

If the icon is flashing between its normal icon and a red cross it indicates the program is PAUSED - use the context menu to unpause.
#comments-end

#Include <Array.au3>

; No command line args = message and exit
If $CmdLine[0] = 0 Then
	MsgBox(48, "ConnStat", "Command format:" & @CRLF & "ConnStat.exe <network connection> [delay]" & @CRLF & @CRLF & 'eg. ConnStat.exe "Local Area Connection 2" 30')
	_Exit()
EndIf

TraySetState()                                                                   ; Show tray icon
$checkConn = $CmdLine[1]                                            ; arg 1 = NIC
If $CmdLine[0] > 1 Then
	If Int($CmdLine[2]) > 0 Then Sleep(Int($CmdLine[2]) * 1000)    ; arg2 = optional delay
EndIf
TraySetState(2)                                                                 ; Hides tray icon appears after delay, ie. monitoring starts
TraySetIcon(@ScriptName, -5)                                         ; Change icon
TraySetState(1)                                                                 ; Show tray icon

While 1
	$connNICs = _AdaptersConnected()                            ; get NICs with state "connected"
	$i = _ArraySearch($connNICs, $checkConn, 1)            ; search NIC list for our adapter
	If @error Then _Exit()                                                   ; exit if not found
	Sleep(1000)
WEnd


Func _Exit()
	Exit
EndFunc

; Function by guiness @ http://www.autoitscript.com/forum/topic/134245-get-netconnection-status/#entry936095
Func _AdaptersConnected($sComputer = @ComputerName)
    Local $aReturn[1] = [0], $iDimension = 0, $oColItems, $oWMIService, $sDelimeter = Chr(01), $sReturn = ""

    $oWMIService = ObjGet("winmgmts:\\" & $sComputer & "\")
    $oColItems = $oWMIService.ExecQuery("Select * From Win32_NetworkAdapter Where NetConnectionStatus='2'", "WQL", 0x30)

    If IsObj($oColItems) Then
        For $oObjItem In $oColItems
            If $oObjItem.AdapterType = "" Or $oObjItem.NetConnectionID = "" Then ; Ensures that the connections are physical adapters.
                ContinueLoop
            EndIf
            If StringInStr($sDelimeter & $sReturn, $sDelimeter & $oObjItem.Description & $sDelimeter, 1) Then ; Ensures there are no duplicates.
                ContinueLoop
            EndIf
            $sReturn &= $oObjItem.Description & $sDelimeter

            If ($aReturn[0] + 1) >= $iDimension Then ; http://www.autoitscript.com/forum/topic/...en-you-have-to-resize-an-exist
                $iDimension = ($aReturn[0] + 1) * 2
                ReDim $aReturn[$iDimension]
            EndIf

            $aReturn[0] += 1
            $aReturn[$aReturn[0]] = $oObjItem.NetConnectionID
        Next
    EndIf

    ReDim $aReturn[$aReturn[0] + 1]
    Return $aReturn
EndFunc   ;==>_AdaptersConnected